@@ -184,6 +184,11 @@ class Builder(SetupInfo):
                         if self.config.rpm or distrib.startswith(('fedora', 'epel')):
                             srpm = self.make_rpm_source_package(distrib, src_tmpdir)
                             self.make_rpm_binary_package(distrib, srpm)
+                            # move logs and rpms to distdir
+                            rpms = glob(osp.join(src_tmpdir, '*.rpm'))
+                            buildlog = glob(osp.join(src_tmpdir, '*.log'))
+                            self.move_package_files(rpms + buildlog, self.get_distrib_dir(distrib))
+                            #
                             if self.config.post_treatments:
                                 self.run_rpm_post_treatments(distrib)
                         else:
@@ -222,8 +227,26 @@ class Builder(SetupInfo):
         .. see::
             http://www.debian.org/doc/debian-policy/ch-source.html
         """
-        self._check_version_mismatch()
-        is_initial_debian_revision = self.is_initial_debian_revision()
+        has_debian_dir = osp.isdir('debian')
+        # Ugly code, does the job for the moment
+        specfile = self.config.specfile
+        if specfile is None:
+            specfiles = glob('*.spec')
+            try:
+                specfile, = specfiles
+            except ValueError:
+                pass
+        if has_debian_dir:
+            self._check_debian_version_mismatch()
+        if specfile is not None:
+            self._check_rpm_version_mismatch(specfile)
+
+        if has_debian_dir:
+            is_initial_debian_revision = self.is_initial_debian_revision()
+        else:
+            # always rebuild the source/orig tarball if debian/ is missing,
+            # skip uscan altogether
+            is_initial_debian_revision = True
         tarball = self.config.orig_tarball
 
         if tarball and is_initial_debian_revision:
@@ -232,8 +255,9 @@ class Builder(SetupInfo):
 
         upstream_name = self.get_upstream_name()
         fileparts = (upstream_name, self.get_upstream_version())
-        # note: tarball format can be guaranteed by uscan's repack option
-        debian_tarball = '%s_%s.orig.tar.gz' % fileparts
+        if has_debian_dir:
+            # note: tarball format can be guaranteed by uscan's repack option
+            debian_tarball = '%s_%s.orig.tar.gz' % fileparts
         upstream_tarball = '%s-%s.tar.gz' % fileparts
 
         # run uscan to download the source tarball by looking at debian/watch
@@ -257,7 +281,7 @@ class Builder(SetupInfo):
                        'Debian revision "%s"' % (debian_name, debian_revision))
                 raise LGPCommandException(msg, err)
             else:
-                tarball = upstream_tarball
+                tarball = osp.join(tmpdir, upstream_tarball)
 
         # create new pristine tarball from working directory if initial revision
         elif tarball is None and is_initial_debian_revision:
@@ -280,17 +304,18 @@ class Builder(SetupInfo):
 
         # Make a copy of tarball ('path/to/xxx-version.tar.gz')...
         # ... with the debian name convention 'path/to/xxx_version.orig.tar.gz'
-        debian_tarball = osp.abspath(osp.join(tmpdir, debian_tarball))
-        try:
-            if not osp.exists(debian_tarball):
-                shutil.copy(tarball, debian_tarball)
-        except EnvironmentError, err:
-            msg = "pristine tarball can't be copied from given location: %s"
-            self.logger.critical(msg % tarball)
-            raise LGPException(err)
+        if has_debian_dir:
+            debian_tarball = osp.abspath(osp.join(tmpdir, debian_tarball))
+            try:
+                if not osp.exists(debian_tarball):
+                    shutil.copy(tarball, debian_tarball)
+            except EnvironmentError, err:
+                msg = "pristine tarball can't be copied from given location: %s"
+                self.logger.critical(msg % tarball)
+                raise LGPException(err)
+            self._debian_tarball = debian_tarball
         #
         self._upstream_tarball = tarball
-        self._debian_tarball = debian_tarball
         return tarball
 
     def make_rpm_source_package(self, distrib, tmpdir):
@@ -305,11 +330,12 @@ class Builder(SetupInfo):
                     self.logger.error("unable to find the '.spec' file")
                 else:
                     self.logger.error("more than one spec file found")
-                self.logger.error("please use the '--specfile' option")
+                self.logger.error("please use the '--spec' option")
                 raise LGPException("cannot build source distribution")
         specfile = osp.abspath(specfile)
 
         # change directory to build source package
+        # note: call os.chdir() HERE is needed in make_rpm_binary_package() below
         os.chdir(tmpdir)
         try:
             cmd = ["sudo", "mock", "--buildsrpm",
@@ -331,7 +357,7 @@ class Builder(SetupInfo):
 
     def make_rpm_binary_package(self, distrib, srpm):
         cmd = ["sudo", "mock", "-r", distrib,
-               "--result", self.get_distrib_dir(distrib),
+               "--resultdir", os.getcwd(), # os.chdir() is called above
                "--rebuild", srpm]
         try:
             self.logger.debug("running mock command: %s ..." % " ".join(cmd))
@@ -663,7 +689,7 @@ class Builder(SetupInfo):
         resultdir = self.get_distrib_dir(distrib)
         try:
             check_call(['createrepo', '--update', '.'], cwd=resultdir)
-        except CalledProcessError, err:
+        except (CalledProcessError, OSError):
             self.logger.warning('cannot update rpm repository for %s', resultdir)
 
     def prepare_source_archive(self, tmpdir, current_distrib):
