@@ -22,10 +22,6 @@ class DistributionTC(TestCase):
     def test_default_distribution(self):
         self.assertItemsEqual(get_distributions(suites=self.suites), self.known)
 
-    def test_distribution_from_changelog(self):
-        self.skipTest('not implemented')
-        self.assertItemsEqual(get_distributions('changelog'), ['unstable'], suites=self.suites)
-
     def test_valid_distribution(self):
         for distrib in self.defined:
             self.assertEqual(get_distributions([distrib,], self.basetgz, suites=self.suites),
@@ -40,13 +36,6 @@ class DistributionTC(TestCase):
         self.assertItemsEqual(get_distributions("all", self.basetgz, suites=self.suites),
                               self.defined)
 
-    def test_one_unvalid_distribution(self):
-        distrib = ['unknown']
-        self.assertRaises(DistributionException, get_distributions, distrib,
-                         basetgz=self.basetgz)
-        distrib = self.defined + distrib
-        self.assertRaises(DistributionException, get_distributions, distrib, self.basetgz)
-
 
 if __name__  == '__main__':
     unittest_main()
